#include <stdio.h>
#include <unistd.h>

#include <pthread.h>

#include "export_to_user.h"
#include "sync.h"

void first_function(curl_mutex_t*);
void second_function(curl_mutex_t*);


int main()
{
	pthread_t thread1;
	pthread_t thread2;
	curl_mutex_t* m;
	int i=0;
	int j=0;
	int err;
	
	/* register the mutex implementations (see syncimpl.c) */
	err= curl_try_register_mutex_functions();
	if (err == -1) {
	        printf("Your thread model is not supported by libcURL.");
		return -1;
	} else if (err !=0) {
	        printf("Some other nasty error occured...");
		return -1;		
	}
	/* now, we can use the mutexes */
	
	/*
	 * We would exactly do this once in libcURL to creat a new mutex (for example
	 * for the (cool) global DNS cache.
	 */
	m= Curl_mutex_new();

	/*
	 * Note that m (curl_mutex_t*) is totally opaque for libcURL.
	 */
	Curl_mutex_lock(m);
	
	pthread_create(&thread1, NULL, (void*) first_function, (void*)m);
        pthread_create(&thread2, NULL, (void*) second_function, (void*)m);
	sleep(5);
	printf("Now the threads\n");
	Curl_mutex_unlock(m);

	pthread_join(thread1, NULL);
        pthread_join(thread2, NULL);
         
	/*
	 * Give the user some chance to close and delete his for this m mutex stuff.
	 */
	Curl_mutex_free(m);

	curl_try_unregister_mutex_functions();

	return 0;
}

void first_function(curl_mutex_t* m)
{
	Curl_mutex_lock(m);
	printf("Inside the first_function\n");
	sleep(2);
	Curl_mutex_unlock(m);
}

void second_function(curl_mutex_t* m)
{
        Curl_mutex_lock(m);
	printf("Inside the second_function\n");
	Curl_mutex_unlock(m);
}

